CREATE TABLE Deca
(
	sifra_deteta CHAR(10) NOT NULL,
	pol_deteta CHAR(1) NOT NULL DEFAULT '0',
	prezime_deteta VARCHAR(20) NOT NULL,
	ime_deteta VARCHAR(20) NOT NULL,
	godiste_deteta INTEGER NOT NULL,
	telefon_deteta VARCHAR(15),
	email_deteta VARCHAR(60),
	adresa_deteta VARCHAR(100) NOT NULL,
CONSTRAINT pk_deca PRIMARY KEY (sifra_deteta)
);

CREATE TABLE Sezone
(
	redni_broj_sezone INTEGER NOT NULL,
	ime_sezone VARCHAR(50) NOT NULL,
  godina_pocetka_sezone INTEGER NOT NULL,
CONSTRAINT pk_sezone PRIMARY KEY (redni_broj_sezone)
);

CREATE TABLE Igraci
(
	redni_broj_sezone INTEGER NOT NULL,
	sifra_deteta CHAR(10) NOT NULL,
CONSTRAINT pk_igraci PRIMARY KEY (redni_broj_sezone, sifra_deteta)
);

CREATE TABLE Kola
(
	redni_broj_sezone INTEGER NOT NULL,
	redni_broj_kola INTEGER NOT NULL,
	datum_kola DATE NOT NULL,
CONSTRAINT pk_kola PRIMARY KEY (redni_broj_sezone,redni_broj_kola)
);

CREATE TABLE Divizije
(
	redni_broj_sezone INTEGER NOT NULL,
	skracenica_divizije CHAR(3) NOT NULL,
	ime_divizije VARCHAR(50) NOT NULL,
CONSTRAINT pk_divizije PRIMARY KEY (redni_broj_sezone,skracenica_divizije)
);

CREATE TABLE Treneri
(
	sifra_trenera CHAR(5) NOT NULL,
	ime_trenera VARCHAR(20) NOT NULL,
	prezime_trenera VARCHAR(20) NOT NULL,
CONSTRAINT pk_treneri PRIMARY KEY (sifra_trenera)
);

CREATE TABLE Tereni
(
	skracenica_terena CHAR(3) NOT NULL,
	ime_terena VARCHAR(50) NOT NULL,
CONSTRAINT pk_tereni PRIMARY KEY (skracenica_terena)
);

CREATE TABLE Termini_Utakmica
(
	skracenica_terena CHAR(3) NOT NULL,
	datum_termina DATE NOT NULL,
	vreme_pocetka_termina TIME NOT NULL,
	redni_broj_sezone INTEGER,
	redni_broj_kola INTEGER,
	redni_broj_utakmice INTEGER,
	vreme_zavrsetka_termina TIME NOT NULL,
CONSTRAINT pk_termini_utakmica PRIMARY KEY (skracenica_terena,datum_termina,vreme_pocetka_termina)
);

CREATE TABLE Timovi
(
	redni_broj_sezone INTEGER NOT NULL,
	skracenica_divizije CHAR(3) NOT NULL,
	takmicarski_broj CHAR(2) NOT NULL,
	sifra_glavnog_trenera CHAR(5) NOT NULL,
	sifra_pomocnog_trenera CHAR(5),
	ime_tima VARCHAR(30) NOT NULL,
	ime_sponzora VARCHAR(30),
CONSTRAINT pk_timovi PRIMARY KEY (redni_broj_sezone,skracenica_divizije,takmicarski_broj)
);

CREATE TABLE Bodovanja
(
	redni_broj_sezone INTEGER NOT NULL,
	broj_bodova_za_pobedu INTEGER NOT NULL DEFAULT 0,
	broj_bodova_za_nereseno INTEGER NOT NULL DEFAULT 0,
	broj_bodova_za_poraz INTEGER NOT NULL DEFAULT 0,
CONSTRAINT pk_bodovanja PRIMARY KEY (redni_broj_sezone)
);

CREATE TABLE Klub
(
	ime_kluba VARCHAR(50) NOT NULL
);

CREATE TABLE Liga
(
	ime_lige VARCHAR(50) NOT NULL
);

CREATE TABLE Utakmice
(
	redni_broj_sezone INTEGER NOT NULL,
	redni_broj_kola INTEGER NOT NULL,
	redni_broj_utakmice INTEGER NOT NULL,
	skracenica_divizije CHAR(3) NOT NULL,
	takmicarski_broj_domaceg_tima CHAR(2) NOT NULL,
	takmicarski_broj_gostujuceg_tima CHAR(2) NOT NULL,
	status_utakmice CHAR(1),
	datum_pocetka_utakmice DATE,
	vreme_pocetka_utakmice TIME,
	broj_pogodaka_domaceg_tima INTEGER NOT NULL DEFAULT 0,
	broj_pogodaka_gostujuceg_tima INTEGER NOT NULL DEFAULT 0,
CONSTRAINT pk_utakmice PRIMARY KEY (redni_broj_sezone,redni_broj_kola,redni_broj_utakmice)
);

CREATE TABLE Statusi_Utakmica
(
	status_utakmice CHAR(1) NOT NULL,
	oznaka_regularnosti CHAR(1) NOT NULL,
	opis_statusa VARCHAR(100) NOT NULL,
CONSTRAINT pk_statusi_utakmica PRIMARY KEY (status_utakmice)
);

CREATE TABLE Ljudski_Polovi
(
	ljudski_pol CHAR(1) NOT NULL DEFAULT '0',
	opis_ljudskog_pola VARCHAR(10) NOT NULL,
CONSTRAINT pk_ljudski_polovi PRIMARY KEY (ljudski_pol)
);

CREATE TABLE Igracke_Registracije
(
	redni_broj_sezone INTEGER NOT NULL,
	skracenica_divizije CHAR(3) NOT NULL,
	takmicarski_broj CHAR(2) NOT NULL,
	registracioni_broj CHAR(2) NOT NULL,
	sifra_deteta CHAR(10),
CONSTRAINT pk_igracke_registracije PRIMARY KEY (redni_broj_sezone,skracenica_divizije,takmicarski_broj,registracioni_broj)
);

CREATE TABLE Regularnosti_Utakmica
(
	oznaka_regularnosti CHAR(1) NOT NULL,
	opis_regularnosti_utakmice VARCHAR(100) NOT NULL,
CONSTRAINT pk_regularnosti_utakmica PRIMARY KEY (oznaka_regularnosti)
);

CREATE TABLE Ugovoreni_Tereni
(
  redni_broj_sezone INTEGER NOT NULL,
  skracenica_terena CHAR(3) NOT NULL,
CONSTRAINT pk_ugovoreni_tereni PRIMARY KEY (redni_broj_sezone,skracenica_terena)
);




ALTER TABLE Igraci
  ADD CONSTRAINT fk_igr_sez
  FOREIGN KEY (redni_broj_sezone) REFERENCES Sezone (redni_broj_sezone)
  ON UPDATE CASCADE ON DELETE RESTRICT;
  
ALTER TABLE Igraci
  ADD CONSTRAINT fk_igr_dec
  FOREIGN KEY (sifra_deteta) REFERENCES Deca (sifra_deteta)
  ON UPDATE CASCADE ON DELETE RESTRICT;
  
ALTER TABLE Igracke_Registracije
  ADD CONSTRAINT fk_ire_igr
  FOREIGN KEY (redni_broj_sezone, sifra_deteta) REFERENCES Igraci (redni_broj_sezone, sifra_deteta)
  ON UPDATE CASCADE ON DELETE RESTRICT;
  
ALTER TABLE Bodovanja
  ADD CONSTRAINT fk_bod_sez
  FOREIGN KEY (redni_broj_sezone) REFERENCES Sezone (redni_broj_sezone)
  ON UPDATE CASCADE ON DELETE CASCADE;
  
ALTER TABLE Kola
  ADD CONSTRAINT fk_kol_sez
  FOREIGN KEY (redni_broj_sezone) REFERENCES Sezone (redni_broj_sezone)
  ON UPDATE CASCADE ON DELETE RESTRICT;

ALTER TABLE Divizije
  ADD CONSTRAINT fk_div_sez
  FOREIGN KEY (redni_broj_sezone) REFERENCES Sezone (redni_broj_sezone)
  ON UPDATE CASCADE ON DELETE RESTRICT;

ALTER TABLE Utakmice
  ADD CONSTRAINT fk_uta_kol
  FOREIGN KEY (redni_broj_sezone,redni_broj_kola) REFERENCES Kola (redni_broj_sezone,redni_broj_kola)
  ON UPDATE CASCADE ON DELETE RESTRICT;

ALTER TABLE Timovi
  ADD CONSTRAINT fk_tim_div
  FOREIGN KEY (redni_broj_sezone,skracenica_divizije) REFERENCES Divizije (redni_broj_sezone,skracenica_divizije)
  ON UPDATE CASCADE ON DELETE RESTRICT;

ALTER TABLE Timovi
  ADD CONSTRAINT fk_tim_tre_pomocni_trener
  FOREIGN KEY (sifra_pomocnog_trenera) REFERENCES Treneri (sifra_trenera)
  ON UPDATE CASCADE ON DELETE RESTRICT;

ALTER TABLE Timovi
  ADD CONSTRAINT fk_tim_tre_glavni_trener
  FOREIGN KEY (sifra_glavnog_trenera) REFERENCES Treneri (sifra_trenera)
  ON UPDATE CASCADE ON DELETE RESTRICT;

ALTER TABLE Termini_Utakmica
  ADD CONSTRAINT fk_tut_ute
  FOREIGN KEY (redni_broj_sezone, skracenica_terena) REFERENCES Ugovoreni_Tereni (redni_broj_sezone, skracenica_terena)
  ON UPDATE CASCADE ON DELETE RESTRICT;

ALTER TABLE Igracke_Registracije
  ADD CONSTRAINT fk_ire_tim
  FOREIGN KEY (redni_broj_sezone,skracenica_divizije,takmicarski_broj) REFERENCES Timovi (redni_broj_sezone,skracenica_divizije,takmicarski_broj)
  ON UPDATE CASCADE ON DELETE RESTRICT;

ALTER TABLE Utakmice
  ADD CONSTRAINT fk_uta_tim_domacin
  FOREIGN KEY (redni_broj_sezone,skracenica_divizije,takmicarski_broj_domaceg_tima) REFERENCES Timovi (redni_broj_sezone,skracenica_divizije,takmicarski_broj)
  ON UPDATE CASCADE ON DELETE RESTRICT;

ALTER TABLE Utakmice
  ADD CONSTRAINT fk_uta_tim_gost
  FOREIGN KEY (redni_broj_sezone,skracenica_divizije,takmicarski_broj_gostujuceg_tima) REFERENCES Timovi (redni_broj_sezone,skracenica_divizije,takmicarski_broj)
  ON UPDATE CASCADE ON DELETE RESTRICT;

ALTER TABLE Termini_Utakmica
  ADD CONSTRAINT fk_tut_uta
  FOREIGN KEY (redni_broj_sezone,redni_broj_kola,redni_broj_utakmice) REFERENCES Utakmice (redni_broj_sezone,redni_broj_kola,redni_broj_utakmice)
  ON UPDATE CASCADE ON DELETE RESTRICT;

ALTER TABLE Utakmice
  ADD CONSTRAINT fk_uta_sut
  FOREIGN KEY (status_utakmice) REFERENCES Statusi_Utakmica (status_utakmice)
  ON UPDATE RESTRICT ON DELETE RESTRICT;

ALTER TABLE Deca
  ADD CONSTRAINT fk_dec_lpo
  FOREIGN KEY (pol_deteta) REFERENCES Ljudski_Polovi (ljudski_pol)
  ON UPDATE RESTRICT ON DELETE RESTRICT;

ALTER TABLE Statusi_Utakmica
  ADD CONSTRAINT fk_sut_rut
  FOREIGN KEY (oznaka_regularnosti) REFERENCES Regularnosti_Utakmica (oznaka_regularnosti)
  ON UPDATE RESTRICT ON DELETE RESTRICT;

ALTER TABLE Ugovoreni_Tereni
  ADD CONSTRAINT fk_ute_sez
  FOREIGN KEY (redni_broj_sezone) REFERENCES Sezone (redni_broj_sezone)
  ON UPDATE RESTRICT ON DELETE RESTRICT;
  
ALTER TABLE Ugovoreni_Tereni
  ADD CONSTRAINT fk_ute_ter
  FOREIGN KEY (skracenica_terena) REFERENCES Tereni (skracenica_terena)
  ON UPDATE RESTRICT ON DELETE RESTRICT;




ALTER TABLE Sezone
  ADD CONSTRAINT ch_sez_redni_broj_sezone
  CHECK (redni_broj_sezone > 0);
  
ALTER TABLE Kola
  ADD CONSTRAINT ch_kol_redni_broj_kola
  CHECK (redni_broj_kola > 0);
  
ALTER TABLE Bodovanja
  ADD CONSTRAINT ch_bod_broj_bodova_za_pobedu
  CHECK (broj_bodova_za_pobedu >= 0);
  
ALTER TABLE Bodovanja
  ADD CONSTRAINT ch_bod_broj_bodova_za_nereseno
  CHECK (broj_bodova_za_nereseno >= 0);
  
ALTER TABLE Bodovanja
  ADD CONSTRAINT ch_bod_broj_bodova_za_poraz
  CHECK (broj_bodova_za_poraz >= 0);
 
ALTER TABLE Utakmice
  ADD CONSTRAINT ch_uta_redni_broj_utakmice
  CHECK (redni_broj_utakmice > 0);  
  
ALTER TABLE Utakmice
  ADD CONSTRAINT ch_uta_broj_pogodaka_domaceg_tima
  CHECK (broj_pogodaka_domaceg_tima >= 0);
  
ALTER TABLE Utakmice
  ADD CONSTRAINT ch_uta_broj_pogodaka_gostujuceg_tima
  CHECK (broj_pogodaka_gostujuceg_tima >= 0);
  
ALTER TABLE Ljudski_Polovi
  ADD CONSTRAINT ch_lpo_ljudski_pol
  CHECK (ljudski_pol IN ('0', '1', '2', '9'));
  
ALTER TABLE Regularnosti_Utakmica
  ADD CONSTRAINT ch_reu_oznaka_regularnoeti
  CHECK (oznaka_regularnosti IN ('N', 'R'));  

ALTER TABLE Utakmice
  ADD CONSTRAINT ch_uta_status_utakmice
  CHECK ((    status_utakmice IS NULL
          AND datum_pocetka_utakmice IS NULL
          AND vreme_pocetka_utakmice IS NULL
          AND broj_pogodaka_domaceg_tima = 0
          AND broj_pogodaka_gostujuceg_tima = 0
         )
         OR 
         (    status_utakmice IS NOT NULL
          AND datum_pocetka_utakmice IS NOT NULL
          AND vreme_pocetka_utakmice IS NOT NULL
        ));

ALTER TABLE Termini_Utakmica
  ADD CONSTRAINT ch_tut_period
  CHECK (vreme_pocetka_termina < vreme_zavrsetka_termina);




CREATE UNIQUE INDEX un_uta_domaci_tim
  ON Utakmice (redni_broj_sezone,
               redni_broj_kola,
               skracenica_divizije,
               takmicarski_broj_domaceg_tima);

CREATE UNIQUE INDEX un_uta_gostujuci_tim
  ON Utakmice (redni_broj_sezone,
               redni_broj_kola,
               skracenica_divizije,
               takmicarski_broj_gostujuceg_tima);

CREATE UNIQUE INDEX un_ira_igrac
  ON Igracke_Registracije (redni_broj_sezone,
                           sifra_deteta);





CREATE OR REPLACE VIEW Pozicije_Timova
(
  redni_broj_sezone,
  skracenica_divizije,
  pozicija,
  ime_tima_i_sponzora,
  ukupan_broj_odigranih_utakmica,
  ukupan_broj_dobijenih_utakmica,
  ukupan_broj_neresenih_utakmica,
  ukupan_broj_izgubljenih_utakmica,
  ukupan_broj_postignutih_pogodaka,
  ukupan_broj_primljenih_pogodaka,
  gol_razlika,
  ukupan_broj_bodova
)
AS
SELECT ishodi.redni_broj_sezone AS redni_broj_sezone,
       ishodi.skracenica_divizije AS skracenica_divizije,
       1 AS pozicija,
       tim.ime_tima || ' - ' || COALESCE(tim.ime_sponzora, '') AS ime_tima_i_sponzora,
       SUM(ishodi.broj_odigranih_utakmica) AS ukupan_broj_odigranih_utakmica,
       SUM(ishodi.broj_dobijenih_utakmica) AS ukupan_broj_dobijenih_utakmica,
       SUM(ishodi.broj_neresenih_utakmica) AS ukupan_broj_neresenih_utakmica,
       SUM(ishodi.broj_izgubljenih_utakmica) AS ukupan_broj_izgubljenih_utakmica,
       SUM(ishodi.broj_postignutih_pogodaka) AS ukupan_broj_postignutih_pogodaka,
       SUM(ishodi.broj_primljenih_pogodaka) AS ukupan_broj_primljenih_pogodaka,
       SUM(ishodi.broj_postignutih_pogodaka - ishodi.broj_primljenih_pogodaka) AS gol_razlika,
       SUM(ishodi.broj_bodova) AS ukupan_broj_bodova
  FROM (SELECT uta.redni_broj_sezone AS redni_broj_sezone,
               uta.skracenica_divizije AS skracenica_divizije,
               uta.takmicarski_broj_domaceg_tima AS takmicarski_broj,
               1 AS broj_odigranih_utakmica,
               CASE WHEN uta.broj_pogodaka_domaceg_tima > uta.broj_pogodaka_gostujuceg_tima
                    THEN 1
                    ELSE 0
               END AS broj_dobijenih_utakmica,
               CASE WHEN uta.broj_pogodaka_domaceg_tima = uta.broj_pogodaka_gostujuceg_tima
                    THEN 1
                    ELSE 0
               END AS broj_neresenih_utakmica,
               CASE WHEN uta.broj_pogodaka_domaceg_tima < uta.broj_pogodaka_gostujuceg_tima
                    THEN 1
                    ELSE 0
               END AS broj_izgubljenih_utakmica,
               uta.broj_pogodaka_domaceg_tima AS broj_postignutih_pogodaka,
               uta.broj_pogodaka_gostujuceg_tima AS broj_primljenih_pogodaka,
               CASE WHEN uta.broj_pogodaka_domaceg_tima > uta.broj_pogodaka_gostujuceg_tima
                    THEN bod.broj_bodova_za_pobedu
                    ELSE 0
               END
               +
               CASE WHEN uta.broj_pogodaka_domaceg_tima = uta.broj_pogodaka_gostujuceg_tima
                    THEN bod.broj_bodova_za_nereseno
                    ELSE 0
               END
               +
               CASE WHEN uta.broj_pogodaka_domaceg_tima < uta.broj_pogodaka_gostujuceg_tima
                    THEN bod.broj_bodova_za_poraz
                    ELSE 0
               END AS broj_bodova
          FROM Utakmice AS uta
               INNER JOIN Statusi_Utakmica AS sut
                 ON sut.status_utakmice = uta.status_utakmice
                AND sut.oznaka_regularnosti = 'R'
               INNER JOIN Bodovanja AS bod
                 ON bod.redni_broj_sezone = uta.redni_broj_sezone
        UNION ALL
        SELECT uta.redni_broj_sezone AS redni_broj_sezone,
               uta.skracenica_divizije AS skracenica_divizije,
               uta.takmicarski_broj_gostujuceg_tima AS takmicarski_broj_gostujuceg_tima,
               1 AS broj_odigranih_utakmica,
               CASE WHEN uta.broj_pogodaka_domaceg_tima < uta.broj_pogodaka_gostujuceg_tima
                    THEN 1
                    ELSE 0
               END AS broj_dobijenih_utakmica,
               CASE WHEN uta.broj_pogodaka_domaceg_tima = uta.broj_pogodaka_gostujuceg_tima
                    THEN 1
                    ELSE 0
               END AS broj_neresenih_utakmica,
               CASE WHEN uta.broj_pogodaka_domaceg_tima > uta.broj_pogodaka_gostujuceg_tima
                    THEN 1
                    ELSE 0
               END AS broj_izgubljenih_utakmica,
               uta.broj_pogodaka_gostujuceg_tima AS broj_postignutih_pogodaka,
               uta.broj_pogodaka_domaceg_tima AS broj_primljenih_pogodaka,
               CASE WHEN uta.broj_pogodaka_domaceg_tima < uta.broj_pogodaka_gostujuceg_tima
                    THEN bod.broj_bodova_za_pobedu
                    ELSE 0
               END
               +
               CASE WHEN uta.broj_pogodaka_domaceg_tima = uta.broj_pogodaka_gostujuceg_tima
                    THEN bod.broj_bodova_za_nereseno
                    ELSE 0
               END
               +
               CASE WHEN uta.broj_pogodaka_domaceg_tima > uta.broj_pogodaka_gostujuceg_tima
                    THEN bod.broj_bodova_za_poraz
                    ELSE 0
               END AS broj_bodova
          FROM Utakmice AS uta
               INNER JOIN Statusi_Utakmica AS sut
                 ON sut.status_utakmice = uta.status_utakmice
                AND sut.oznaka_regularnosti = 'R'
               INNER JOIN Bodovanja AS bod
                 ON bod.redni_broj_sezone = uta.redni_broj_sezone
       ) AS ishodi
       INNER JOIN Timovi AS tim
         ON tim.redni_broj_sezone = ishodi.redni_broj_sezone
        AND tim.skracenica_divizije = ishodi.skracenica_divizije
        AND tim.takmicarski_broj = ishodi.takmicarski_broj
 GROUP BY ishodi.redni_broj_sezone,
          ishodi.skracenica_divizije,
          tim.takmicarski_broj,
          tim.ime_tima,
          tim.ime_sponzora
 ORDER BY ukupan_broj_bodova DESC, gol_razlika DESC, ukupan_broj_postignutih_pogodaka DESC, ukupan_broj_odigranih_utakmica DESC;
 
 
 

CREATE VIEW Nerasporedjeni_Igraci
(
  redni_broj_sezone,
  sifra_deteta,
  ime_deteta,
  prezime_deteta,
  godiste_deteta,
  pol_deteta,
  opis_ljudskog_pola
)
AS
SELECT i.redni_broj_sezone, i.sifra_deteta,
       d.ime_deteta, d.prezime_deteta, d.godiste_deteta, d.pol_deteta, p.opis_ljudskog_pola
  FROM Deca AS d
       INNER JOIN Ljudski_Polovi AS p
         ON p.ljudski_pol = d.pol_deteta
       INNER JOIN Igraci AS i
         ON i.sifra_deteta = d.sifra_deteta
 WHERE NOT EXISTS (SELECT sifra_deteta
                     FROM Igracke_Registracije AS r
                    WHERE r.redni_broj_sezone = i.redni_broj_sezone
                      AND r.sifra_deteta = i.sifra_deteta);
                      
                      
                      

CREATE VIEW Statistike_Timova
(
  redni_broj_sezone,
  skracenica_divizije,
  takmicarski_broj,
  ime_tima,
  broj_igraca,
  prosecna_starost_igraca
)
AS
SELECT t.redni_broj_sezone, t.skracenica_divizije, t.takmicarski_broj, t.ime_tima,
       COUNT(r.sifra_deteta),
       AVG(s.godina_pocetka_sezone-d.godiste_deteta)
  FROM Timovi AS t
       INNER JOIN Igracke_Registracije AS r
         ON r.redni_broj_sezone = t.redni_broj_sezone
        AND r.skracenica_divizije = t.skracenica_divizije
        AND r.takmicarski_broj = t.takmicarski_broj
       INNER JOIN Deca AS d
         ON d.sifra_deteta = r.sifra_deteta
       INNER JOIN Sezone AS s
         ON s.redni_broj_sezone = r.redni_broj_sezone
 GROUP BY t.redni_broj_sezone, t.skracenica_divizije, t.takmicarski_broj, t.ime_tima;
 



CREATE VIEW Statistike_Timova_Po_Godistima
(
  redni_broj_sezone,
  skracenica_divizije,
  takmicarski_broj,
  ime_tima,
  godiste_igraca,
  broj_igraca
)
AS
SELECT t.redni_broj_sezone,
       t.skracenica_divizije,
       t.takmicarski_broj,
       t.ime_tima,
       d.godiste_deteta,
       COUNT(r.sifra_deteta)
  FROM Timovi AS t
       INNER JOIN Igracke_Registracije AS r
         ON r.redni_broj_sezone = t.redni_broj_sezone
        AND r.skracenica_divizije = t.skracenica_divizije
        AND r.takmicarski_broj = t.takmicarski_broj
       INNER JOIN Deca AS d
         ON d.sifra_deteta = r.sifra_deteta
 GROUP BY t.redni_broj_sezone, t.skracenica_divizije, t.takmicarski_broj, t.ime_tima, d.godiste_deteta;




CREATE VIEW Statistike_Divizija_Po_Godistima
(
  redni_broj_sezone,
  skracenica_divizije,
  ime_divizije,
  godiste_igraca,
  broj_igraca
)
AS
SELECT di.redni_broj_sezone,
       di.skracenica_divizije,
       di.ime_divizije,
       de.godiste_deteta,
       COUNT(r.sifra_deteta)
  FROM Divizije AS di
       INNER JOIN Timovi AS t
         ON t.redni_broj_sezone = di.redni_broj_sezone
        AND t.skracenica_divizije = di.skracenica_divizije
       INNER JOIN Igracke_Registracije AS r
         ON r.redni_broj_sezone = t.redni_broj_sezone
        AND r.skracenica_divizije = t.skracenica_divizije
        AND r.takmicarski_broj = t.takmicarski_broj
       INNER JOIN Deca AS de
         ON de.sifra_deteta = r.sifra_deteta
 GROUP BY di.redni_broj_sezone, di.skracenica_divizije, di.ime_divizije, de.godiste_deteta;




CREATE VIEW Nekompletna_Kola
(
  redni_broj_sezone,
  redni_broj_kola,
  datum_kola,
  skracenica_divizije
)
AS
SELECT d.redni_broj_sezone, k.redni_broj_kola, k.datum_kola, d.skracenica_divizije
  FROM Divizije AS d
       INNER JOIN Kola AS k
         ON k.redni_broj_sezone = d.redni_broj_sezone
       LEFT OUTER JOIN Utakmice AS u
         ON u.redni_broj_sezone = d.redni_broj_sezone
        AND u.redni_broj_kola = k.redni_broj_kola
        AND u.skracenica_divizije = d.skracenica_divizije
 GROUP BY d.redni_broj_sezone, k.redni_broj_kola, k.datum_kola, d.skracenica_divizije
HAVING COUNT(k.redni_broj_kola) < (SELECT TRUNC(COUNT(*) / 2)
                     FROM Timovi AS t
                    WHERE t.redni_broj_sezone = d.redni_broj_sezone
                      AND t.skracenica_divizije = d.skracenica_divizije);




CREATE VIEW Raspored_Utakmica
(
  redni_broj_sezone,
  skracenica_terena,
  datum_termina,
  vreme_pocetka_termina,
  vreme_zavrsetka_termina,
  redni_broj_kola,
  redni_broj_utakmice,
  skracenica_divizije,
  takmicarski_broj_domaceg_tima,
  ime_domaceg_tima,
  takmicarski_broj_gostujuceg_tima,
  ime_gostujuceg_tima
)
AS
SELECT t.redni_broj_sezone, t.skracenica_terena,
       t.datum_termina, t.vreme_pocetka_termina, t.vreme_zavrsetka_termina,
       u.redni_broj_kola, u.redni_broj_utakmice, u.skracenica_divizije,
       u.takmicarski_broj_domaceg_tima, dom.ime_tima,
       u.takmicarski_broj_gostujuceg_tima, gos.ime_tima
  FROM Termini_Utakmica AS t
       INNER JOIN Utakmice AS u
         ON t.redni_broj_sezone = u.redni_broj_sezone
        AND t.redni_broj_kola = u.redni_broj_kola
        AND t.redni_broj_utakmice = u.redni_broj_utakmice
       INNER JOIN Timovi AS dom
         ON u.redni_broj_sezone = dom.redni_broj_sezone
        AND u.skracenica_divizije = dom.skracenica_divizije
        AND u.takmicarski_broj_domaceg_tima = dom.takmicarski_broj
       INNER JOIN Timovi AS gos
         ON u.redni_broj_sezone = gos.redni_broj_sezone
        AND u.skracenica_divizije = gos.skracenica_divizije
        AND u.takmicarski_broj_gostujuceg_tima = gos.takmicarski_broj;
        
        
        

CREATE VIEW Sastavi_Timova
(
  redni_broj_sezone,
  skracenica_divizije,
  takmicarski_broj,
  registracioni_broj,
  sifra_deteta,
  prezime_deteta,
  ime_deteta,
  godiste_deteta,
  telefon_deteta,
  email_deteta,
  adresa_deteta,
  opis_pola_deteta
)
AS
SELECT t.redni_broj_sezone, t.skracenica_divizije, t.takmicarski_broj,
       r.registracioni_broj, r.sifra_deteta,
       d.prezime_deteta, d.ime_deteta, d.godiste_deteta,
       d.telefon_deteta, d.email_deteta, d.adresa_deteta,
       p.opis_ljudskog_pola
  FROM Timovi AS t
       INNER JOIN Igracke_Registracije AS r
         ON t.redni_broj_sezone = r.redni_broj_sezone
        AND t.skracenica_divizije = r.skracenica_divizije
        AND t.takmicarski_broj = r.takmicarski_broj
       INNER JOIN Igraci AS i
         ON r.redni_broj_sezone = i.redni_broj_sezone
        AND r.sifra_deteta = i.sifra_deteta
       INNER JOIN Deca AS d
         ON i.sifra_deteta = d.sifra_deteta
       INNER JOIN Ljudski_Polovi AS p
         ON d.pol_deteta = p.ljudski_pol;
         
         
         
         



INSERT INTO Ljudski_Polovi (ljudski_pol, opis_ljudskog_pola) VALUES ('0', 'Nepoznat');
INSERT INTO Ljudski_Polovi (ljudski_pol, opis_ljudskog_pola) VALUES ('1', 'Muski');
INSERT INTO Ljudski_Polovi (ljudski_pol, opis_ljudskog_pola) VALUES ('2', 'Zenski');
INSERT INTO Ljudski_Polovi (ljudski_pol, opis_ljudskog_pola) VALUES ('9', 'Nebitan');


INSERT INTO Statusi_Utakmica (status_utakmice, oznaka_regularnosti, opis_statusa) VALUES ('1', 'R', 'Regularno odigrana utakmica');
INSERT INTO Statusi_Utakmica (status_utakmice, oznaka_regularnosti, opis_statusa) VALUES ('2', 'N', 'Utakmica prekinuta zbog vise sile');
INSERT INTO Statusi_Utakmica (status_utakmice, oznaka_regularnosti, opis_statusa) VALUES ('3', 'N', 'Utakmica uopste nije ordigrana zbog vise sile');
INSERT INTO Statusi_Utakmica (status_utakmice, oznaka_regularnosti, opis_statusa) VALUES ('4', 'R', 'Jedan od timova je predao utakmicu');


INSERT INTO Regularnosti_Utakmica (oznaka_regularnosti, opis_regularnosti_utakmice) VALUES ('N', 'Neregularna');
INSERT INTO Regularnosti_Utakmica (oznaka_regularnosti, opis_regularnosti_utakmice) VALUES ('R', 'Regularna');


COMMIT;
        
